@@ -1611,7 +1611,7 @@ void splitGroups(vector<floattype>& y, vector<unsigned int>& nodes , bool useLap
 	}else{
 		do_normalPartitionAlgorithm:
 
-		if (debug_level > 0) cerr << getTime() << " [DEBUG] perfoming a normal split of " << nodes.size()<< " nodes" << endl;
+		if (debug_level > 0) cerr << getTime() << " [DEBUG] performing a normal split of " << nodes.size()<< " nodes" << endl;
 
 		// Store data about two groups (Zero cannot be assigned with certainty)
 		map<unsigned int,bool> groupA, groupB, groupZero;
