@@ -820,7 +820,7 @@ if __name__ == '__main__':
 
     edg = sum(map(len, selectedRuns))
 
-    matchfile = args.dist_file.rsplit('.')[0]+'.matching'
+    matchfile = args.dist_file+'.matching'
     printMatching(g1_mod, g2_mod, g1_runs, multiChrom, matchfile)
 
     #
