@@ -27,9 +27,9 @@
 # 
 # @author Paul Klemm
 # @email klemmp@staff.uni-marburg.de
-# @company Bioinformatics, University of Leipzig
-# @version 6
-# @date 2-10-2021
+# @company Bioinformatics, University of Marburg
+# @version 7
+# @date 23-12-2021
 #
 ##########################################################################################
 
@@ -39,6 +39,7 @@ use threads::shared;
 use POSIX;
 use File::Basename;
 use Thread::Queue;
+use Cwd 'abs_path';
 our $QUEUE = Thread::Queue->new();    # A new empty queue
 
 my $usage = <<'ENDUSAGE';
@@ -142,7 +143,15 @@ for(my $v = 0 ; $v < scalar @ARGV_copy ; $v++){
 	elsif($ARGV_copy[$v] =~ m/^--?exact$/){$exact=1;}
 	elsif($ARGV_copy[$v] =~ m/^-.+/){print $usage; print STDERR "ERROR: invalid option ".$ARGV_copy[$v]."!\n\n";exit(1);}
 	elsif(!defined($query)){$query = $ARGV_copy[$v];}
-	else{$ARGV_copyiddone[$v]=0;$ARGV_copyiddone_counter--;}
+	else{
+		# 6.0.32 replace files if there is a *_clean* present
+		if(-e $ARGV_copy[$v]){
+			my $file_clean = abs_path $ARGV_copy[$v];
+			$file_clean=~s/(\.[^.]+)$/_clean$1/;
+			if(-e $file_clean){$ARGV_copy[$v] = $file_clean}
+		}
+		$ARGV_copyiddone[$v]=0;$ARGV_copyiddone_counter--;
+	}
 }
 if ($help){
     print $usage;
@@ -223,6 +232,10 @@ unless(open(my $FH,'<',$query)) {
 			if(length($sp[$v])==0 || $sp[$v] eq ""){next;}
 			$sp[$v]=~s/^\(//;$sp[$v]=~s/\)$//;
 
+			my @arr = split(" ",$sp[$v]); # 6.0.32 , -> ; 
+	        $arr[0]=~s/,/;/g;
+	        $sp[$v]=join(" ",@arr);
+
 			$qdata{"STDIN"}{$sp[$v]}=$sp[$v];
 			$genecounter++;
 		}
@@ -335,7 +348,11 @@ sub worker {
 					if(scalar(@arr)>0){$genename=$arr[0];}
 					$genename=~s/^>//;
 
-					if(exists $qdata{$basename}{$genename}){
+					my @arr = split(" ",$genename); # 6.0.32 , -> ; 
+			        $arr[0]=~s/,/;/g;
+			        my $genename_no_comma=join(" ",@arr);
+			        
+					if(exists $qdata{$basename}{$genename_no_comma}){
 					
 						my $headerstr=$curLine;
 						if($source){$headerstr=$headerstr." ".$basename;}
@@ -355,10 +372,13 @@ sub worker {
 							if(!defined $qdata{$filename}{$key}){next}
 
 							my $regexv = $key; 
+					        
 							my $curLine_test = $curLine;
-							
+
 							if(!$doregex && !$exact){$regexv=quotemeta($regexv);}
 
+							$regexv=~s/;/[,;]/g; # 6.0.32 , -> ; 
+
 							my $test_match = 0;
 							if( !$exact ){
 								
